import { request, getRequestParameter } from '@/utils/request';
import { getUserInfo } from '@/utils/auth';
import qs from 'qs';

/**
 * @description 得到语言列表
 */
export function GetLanguageList() {
  let params = getRequestParameter('language_manager-GetLanguageList');

  return request({
    method: 'post',
    url: process.env.VUE_APP_FILE_SERVE,
    params
  });
}

/**
 * @description 获取词汇包
 * @param { object } language_type 语言类型 word_key_list 词汇键值列表
 */
export function GetWordPack(Parameter) {
  let data = {
    MethodName: 'language_manager-GetWordPack',
    Parameter: JSON.stringify(Parameter)
  };
  return request({
    method: 'post',
    url: process.env.VUE_APP_FILE_SERVE,
    data,
    transformRequest: [
      function (data) {
        return qs.stringify(data);
      }
    ],
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'
    }
  });
}

/**
 * @description 上传文件
 * @param {String} SecurityLevel 保密级别
 * @returns
 */
export function fileUpload(SecurityLevel, file) {
  const { session_id, user_code, user_type } = getUserInfo();
  let params = {
    UserCode: user_code,
    UserType: user_type,
    SessionID: session_id,
    SecurityLevel
  };
  const formData = new FormData();
  formData.append(file.filename, file.file, file.file.name);

  return request({
    method: 'post',
    url: 'GCLSFileServer/WebFileUpload',
    params,
    headers: {
      'Content-Type': 'multipart/form-data'
    },
    data: formData
  });
}
