/**
 * @description WebSDK 实例化对象
 */
let rtc;

/**
 * @method initSDK
 * @description 初始化SDK方法
 * @param { object } data 初始化SDK所需参数
 * @returns { object }
 */
export function initSDK(data) {
  rtc = new Rtc(data);
  return rtc;
}

/**
 * @method startLive
 * @description 开启直播
 */
export function startLive() {
  rtc.startLive({
    success(data) {
      console.log(data);
      alert('开启直播成功');
    },
    fail(data) {
      alert(`开启直播失败：${data}`);
    }
  });
}

/**
 * @method publishStream
 * @description 推送本地流
 */
export function publishStream() {
  rtc.publish({
    streamName: 'main',
    // 推流成功，更新上麦结果
    success: function (stream) {
      console.log(stream);
      // rtc.updateMcResult({
      //   pid: 1,
      //   stid: stream.id(),
      //   success: function (data) {
      //     alert('更新上麦结果请求成功，此处可处理应用层逻辑' + JSON.stringify(data));
      //   },
      //   fail: function (data) {
      //     alert('更新上麦结果请求失败，此处可处理应用层逻辑' + JSON.stringify(data));
      //   }
      // });
    },
    fail: function (str) {
      // 推流失败，更新上麦结果
      alert(str);
    }
  });
}

/**
 * @method createLocalStram
 * @description 创建本地流
 */
export function createLocalStream() {
  const createData = {
    video: true,
    audio: true
  };
  rtc.createLocalStream({
    streamName: 'main',
    createData,
    success: function (stream) {
      console.log('创建本地流成功', stream);
      // 创建本地流成功，将流展示到id为 live 的dom元素盒子中
      stream.show('live');
      startLive();
      publishStream(stream); // 如果需要立即推流，执行 publish 方法
    },
    fail: function (data) {
      // 创建本地流失败，应用层处理
      console.log(data);
      alert('创建本地流失败');
    }
  });
}

/**
 * @method initListener
 * @description 初始化监听事件
 */
export function initListener(vue) {
  rtc.on('login_success', data => {
    console.log('登录成功', data);
    vue.roomData = data;
  });

  rtc.on('login_failed', data => {
    console.log('登录失败', data);
    alert('登录失败：' + JSON.stringify(data));
  });

  // 必须在加入房间成功的“conference_join”事件回调里创建本地流
  rtc.on('conference_join', () => {
    // 有监听就是加入房间成功
    createLocalStream();
  });

  rtc.on('conference_join_failed', err => {
    // 加入房间失败  err为错误原因
    console.log('加入房间失败', err);
  });

  // 房间全量信息事件
  rtc.on('room_context', roomData => {
    console.log(JSON.parse(roomData));
  });

  rtc.on('publish_stream', str => {
    console.log('直播已开启', str);
  });

  rtc.on('end_stream', str => {
    console.log('直播已关闭', str);
  });

  rtc.on('switch_user_settings', settingData => {
    // 单个用户配置监听
    console.log(settingData);
  });

  rtc.on('speak_context', speakData => {
    console.log(speakData); // 人员列表事件（人员麦序变化时广播）
  });

  rtc.on('switch_settings', data => {
    console.log(data); // 房间设置事件
  });

  rtc.on('allow_sub', stream => {
    alert('监听到有流');
    rtc.trySubscribeStream({
      tryStream: stream,
      success: function success(stream) {
        stream.show('other');
      },
      fail: function fail(err) {
        console.error(err);
      }
    });
  });

  rtc.on('publishStreamErr', data => {
    console.log('推流意外终止:' + data.streamName);
    // 直播开启状态下，尝试重推这条流
  });

  // 视频无法自动播放
  rtc.on('playError', data => {
    console.log(data);
  });

  // 监听聊天事件
  rtc.on('chat_message', data => {
    let dat = JSON.parse(data);
    // data数据需要解析
    if (dat.isFilterChat && dat.isFilterChat === 1) {
      return;
    }
  });
}

/**
 * @method stopLive
 * @description 结束直播
 */
export function stopLive() {
  rtc.stopLive({
    success(data) {
      alert('结束直播成功：' + JSON.stringify(data));
    },
    fail(data) {
      alert('结束直播失败：' + JSON.stringify(data));
    }
  });
}

/**
 * @method closeVideo
 * @description 结束本地流
 */
export function closeVideo() {
  rtc.closeVideo({
    streamName: 'main',
    success: function () {
      console.log('结束本地流成功');
    },
    fail: function (str) {
      console.log(str);
    }
  });
}

/**
 * @method handsUp
 * @description 申请连麦
 */
export function handsUp(data) {
  rtc.handsUp(data);
}

/**
 * @method pauseAudio
 * @description 关闭本地流声音
 */
export function pauseAudio() {
  rtc.pauseAudio({
    streamName: 'main',
    success: function () {
      console.log('关闭本地流声音成功');
    },
    fail: function (str) {
      console.log(str);
    }
  });
}

/**
 * @method playAudio
 * @description 开启本地流声音
 */
export function playAudio() {
  rtc.playAudio({
    streamName: 'main',
    success: function () {
      console.log('开启本地流声音成功');
    },
    fail: function (str) {
      console.log(str);
    }
  });
}

/**
 * @method pauseVideo
 * @description 关闭本地流视频画面
 */
export function pauseVideo() {
  rtc.pauseVideo({
    streamName: 'main',
    success: function () {
      console.log('关闭本地流视频画面成功');
    },
    fail: function (str) {
      console.log(str);
    }
  });
}

/**
 * @method playVideo
 * @description 开启本地流视频画面
 */
export function playVideo() {
  rtc.playVideo({
    streamName: 'main',
    success: function () {
      console.log('开启本地流视频画面成功');
    },
    fail: function (str) {
      console.log(str);
    }
  });
}

/**
 * @description 查询直播是否开启
 */
export function getLiveStat() {
  rtc.getLiveStat({
    success: function (data) {
      console.log('直播开启状态');
      console.log(data);
    },
    fail: function (str) {
      console.log('直播关闭状态或查询直播失败', str);
    }
  });
}

/**
 * @description 开启、结束、暂停、恢复录制
 * @param { String } status: 'start' 开启, 'end' 结束, 'pause' 暂停, 'resume' 恢复
 */
export function liveRecord(status) {
  rtc.liveRecord({
    status: status,
    success: function (data) {
      console.log('成功', data);
    },
    fail: function (str) {
      console.log(str);
    }
  });
}

// 聊天组件

/**
 * @descrption 发送聊天
 * @param {String} msg length不能超过400
 */
export function sendMsg(msg) {
  rtc.sendMsg(msg);
}

export function roomUpdate() {
  rtc.roomUpdate();
}
